@@ -1,3 +1,5 @@
+import pytest
+
 from blinker import Signal
 
 
@@ -34,7 +36,16 @@ def test_temp_connection_for_sender():
     assert not sig.receivers
 
 
-def test_temp_connection_failure():
+class Failure(Exception):
+    pass
+
+
+class BaseFailure(BaseException):
+    pass
+
+
+@pytest.mark.parametrize("exc_type", [Failure, BaseFailure])
+def test_temp_connection_failure(exc_type):
     sig = Signal()
 
     canary = []
@@ -45,16 +56,12 @@ def test_temp_connection_failure():
     class Failure(Exception):
         pass
 
-    try:
+    with pytest.raises(exc_type):  # noqa: B908
         sig.send(1)
         with sig.connected_to(receiver):
             sig.send(2)
-            raise Failure
+            raise exc_type
         sig.send(3)
-    except Failure:
-        pass
-    else:
-        raise AssertionError("Context manager did not propagate.")
 
     assert canary == [2]
     assert not sig.receivers
